@@ -1,5 +1,8 @@
 package Business::ID::NIK;
 
+our $DATE = '2015-07-01'; # DATE
+our $VERSION = '0.06'; # VERSION
+
 use 5.010001;
 use warnings;
 use strict;
@@ -12,8 +15,6 @@ require Exporter;
 our @ISA = qw(Exporter);
 our @EXPORT = qw(parse_nik);
 
-our $VERSION = '0.05'; # VERSION
-
 our %SPEC;
 
 $SPEC{parse_nik} = {
@@ -22,6 +23,7 @@ $SPEC{parse_nik} = {
     args => {
         nik => {
             summary => 'Input NIK to be validated',
+            schema => 'str*',
             pos => 0,
             req => 1,
         },
@@ -95,7 +97,7 @@ sub parse_nik {
 }
 
 1;
-# ABSTRACT: Validate Indonesian citizenship registration number (NIK)
+# ABSTRACT: Parse Indonesian citizenship registration number (NIK)
 
 __END__
 
@@ -105,11 +107,11 @@ __END__
 
 =head1 NAME
 
-Business::ID::NIK - Validate Indonesian citizenship registration number (NIK)
+Business::ID::NIK - Parse Indonesian citizenship registration number (NIK)
 
 =head1 VERSION
 
-This document describes version 0.05 of Business::ID::NIK (from Perl distribution Business-ID-NIK), released on 2014-08-16.
+This document describes version 0.06 of Business::ID::NIK (from Perl distribution Business-ID-NIK), released on 2015-07-01.
 
 =head1 SYNOPSIS
 
@@ -153,14 +155,12 @@ Whether to check for known locality (city) codes.
 
 Whether to check for known province codes.
 
-=item * B<nik>* => I<any>
+=item * B<nik>* => I<str>
 
 Input NIK to be validated.
 
 =back
 
-Return value:
-
 Returns an enveloped result (an array).
 
 First element (status) is an integer containing HTTP status code
@@ -170,7 +170,7 @@ First element (status) is an integer containing HTTP status code
 element (meta) is called result metadata and is optional, a hash
 that contains extra information.
 
- (any)
+Return value:  (any)
 
 =head1 HOMEPAGE
 
@@ -178,7 +178,7 @@ Please visit the project's homepage at L<https://metacpan.org/release/Business-I
 
 =head1 SOURCE
 
-Source repository is at L<https://github.com/sharyanto/perl-Business-ID-NIK>.
+Source repository is at L<https://github.com/perlancar/perl-Business-ID-NIK>.
 
 =head1 BUGS
 
@@ -190,11 +190,11 @@ feature.
 
 =head1 AUTHOR
 
-Steven Haryanto <stevenharyanto@gmail.com>
+perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by Steven Haryanto.
+This software is copyright (c) 2015 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
